# JimuFlow

JimuFlow is a simple and easy-to-use cross-platform RPA tool that allows you to develop and run RPA applications on Windows, Linux, and MacOS.

The currently supported commands are categorized as follows:

1. **Basic Commands**: Including process control, waiting, data processing, etc.
2. **Operating System Commands**: Including file operations, process management, clipboard operations, etc.
3. **Mouse and Keyboard Commands**: Used to simulate user mouse and keyboard operations.
4. **Data Table Commands**: Used to manipulate table data, supporting Excel and CSV formats.
5. **Web Automation Commands**: Used to operate browsers and web pages, supporting Windows, Linux, and MacOS.
6. **Windows Automation Commands**: Used to control windowed applications on Windows.

## Useful links

- [JimuFlow on GitHub](https://github.com/jimu-flow/jimu-flow)
- [JimuFlow on Gitee](https://gitee.com/incoding/jimuflow)
- [JimuFlow Website](https://jimuflow.readthedocs.io/en/)
